# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import group_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/organizationmanager/v1/group_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a/yandex/cloud/organizationmanager/v1/group.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x0fGetGroupRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x95\x01\n\x11ListGroupsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"i\n\x12ListGroupsResponse\x12:\n\x06groups\x18\x01 \x03(\x0b\x32*.yandex.cloud.organizationmanager.v1.Group\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x92\x01\n\x12\x43reateGroupRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x04name\x18\x02 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"\'\n\x13\x43reateGroupMetadata\x12\x10\n\x08group_id\x18\x01 \x01(\t\"\xb9\x01\n\x12UpdateGroupRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\"\'\n\x13UpdateGroupMetadata\x12\x10\n\x08group_id\x18\x01 \x01(\t\"4\n\x12\x44\x65leteGroupRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x13\x44\x65leteGroupMetadata\x12\x10\n\x08group_id\x18\x01 \x01(\t\"{\n\x1aListGroupOperationsRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"m\n\x1bListGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"x\n\x17ListGroupMembersRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"v\n\x18ListGroupMembersResponse\x12\x41\n\x07members\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.organizationmanager.v1.GroupMember\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x0bGroupMember\x12\x12\n\nsubject_id\x18\x01 \x01(\t\x12\x14\n\x0csubject_type\x18\x02 \x01(\t\"\x90\x01\n\x19UpdateGroupMembersRequest\x12\x1e\n\x08group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12S\n\rmember_deltas\x18\x02 \x03(\x0b\x32\x30.yandex.cloud.organizationmanager.v1.MemberDeltaB\n\x82\xc8\x31\x06\x31-1000\".\n\x1aUpdateGroupMembersMetadata\x12\x10\n\x08group_id\x18\x01 \x01(\t\"\xc8\x01\n\x0bMemberDelta\x12S\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32=.yandex.cloud.organizationmanager.v1.MemberDelta.MemberActionB\x04\xe8\xc7\x31\x01\x12 \n\nsubject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"B\n\x0cMemberAction\x12\x1d\n\x19MEMBER_ACTION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x32\xee\x11\n\x0cGroupService\x12\x9b\x01\n\x03Get\x12\x34.yandex.cloud.organizationmanager.v1.GetGroupRequest\x1a*.yandex.cloud.organizationmanager.v1.Group\"2\x82\xd3\xe4\x93\x02,\x12*/organization-manager/v1/groups/{group_id}\x12\xa0\x01\n\x04List\x12\x36.yandex.cloud.organizationmanager.v1.ListGroupsRequest\x1a\x37.yandex.cloud.organizationmanager.v1.ListGroupsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/organization-manager/v1/groups\x12\xb0\x01\n\x06\x43reate\x12\x37.yandex.cloud.organizationmanager.v1.CreateGroupRequest\x1a!.yandex.cloud.operation.Operation\"J\xb2\xd2*\x1c\n\x13\x43reateGroupMetadata\x12\x05Group\x82\xd3\xe4\x93\x02$\"\x1f/organization-manager/v1/groups:\x01*\x12\xbb\x01\n\x06Update\x12\x37.yandex.cloud.organizationmanager.v1.UpdateGroupRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*\x1c\n\x13UpdateGroupMetadata\x12\x05Group\x82\xd3\xe4\x93\x02/2*/organization-manager/v1/groups/{group_id}:\x01*\x12\xc8\x01\n\x06\x44\x65lete\x12\x37.yandex.cloud.organizationmanager.v1.DeleteGroupRequest\x1a!.yandex.cloud.operation.Operation\"b\xb2\xd2*,\n\x13\x44\x65leteGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02,**/organization-manager/v1/groups/{group_id}\x12\xd2\x01\n\x0eListOperations\x12?.yandex.cloud.organizationmanager.v1.ListGroupOperationsRequest\x1a@.yandex.cloud.organizationmanager.v1.ListGroupOperationsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/organization-manager/v1/groups/{group_id}/operations\x12\xca\x01\n\x0bListMembers\x12<.yandex.cloud.organizationmanager.v1.ListGroupMembersRequest\x1a=.yandex.cloud.organizationmanager.v1.ListGroupMembersResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/organization-manager/v1/groups/{group_id}:listMembers\x12\xee\x01\n\rUpdateMembers\x12>.yandex.cloud.organizationmanager.v1.UpdateGroupMembersRequest\x1a!.yandex.cloud.operation.Operation\"z\xb2\xd2*3\n\x1aUpdateGroupMembersMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=\"8/organization-manager/v1/groups/{group_id}:updateMembers:\x01*\x12\xbf\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/organization-manager/v1/groups/{resource_id}:listAccessBindings\x12\xfe\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x96\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x44\"?/organization-manager/v1/groups/{resource_id}:setAccessBindings:\x01*\x12\x8a\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x9c\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02G\"B/organization-manager/v1/groups/{resource_id}:updateAccessBindings:\x01*B\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _GETGROUPREQUEST.fields_by_name['group_id']._options = None
  _GETGROUPREQUEST.fields_by_name['group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTGROUPSREQUEST.fields_by_name['organization_id']._options = None
  _LISTGROUPSREQUEST.fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTGROUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTGROUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTGROUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTGROUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _LISTGROUPSREQUEST.fields_by_name['filter']._options = None
  _LISTGROUPSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATEGROUPREQUEST.fields_by_name['organization_id']._options = None
  _CREATEGROUPREQUEST.fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEGROUPREQUEST.fields_by_name['name']._options = None
  _CREATEGROUPREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEGROUPREQUEST.fields_by_name['description']._options = None
  _CREATEGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEGROUPREQUEST.fields_by_name['group_id']._options = None
  _UPDATEGROUPREQUEST.fields_by_name['group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEGROUPREQUEST.fields_by_name['name']._options = None
  _UPDATEGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEGROUPREQUEST.fields_by_name['description']._options = None
  _UPDATEGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _DELETEGROUPREQUEST.fields_by_name['group_id']._options = None
  _DELETEGROUPREQUEST.fields_by_name['group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTGROUPOPERATIONSREQUEST.fields_by_name['group_id']._options = None
  _LISTGROUPOPERATIONSREQUEST.fields_by_name['group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTGROUPOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTGROUPOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _LISTGROUPMEMBERSREQUEST.fields_by_name['group_id']._options = None
  _LISTGROUPMEMBERSREQUEST.fields_by_name['group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTGROUPMEMBERSREQUEST.fields_by_name['page_size']._options = None
  _LISTGROUPMEMBERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTGROUPMEMBERSREQUEST.fields_by_name['page_token']._options = None
  _LISTGROUPMEMBERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _UPDATEGROUPMEMBERSREQUEST.fields_by_name['group_id']._options = None
  _UPDATEGROUPMEMBERSREQUEST.fields_by_name['group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEGROUPMEMBERSREQUEST.fields_by_name['member_deltas']._options = None
  _UPDATEGROUPMEMBERSREQUEST.fields_by_name['member_deltas']._serialized_options = b'\202\3101\0061-1000'
  _MEMBERDELTA.fields_by_name['action']._options = None
  _MEMBERDELTA.fields_by_name['action']._serialized_options = b'\350\3071\001'
  _MEMBERDELTA.fields_by_name['subject_id']._options = None
  _MEMBERDELTA.fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GROUPSERVICE.methods_by_name['Get']._options = None
  _GROUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002,\022*/organization-manager/v1/groups/{group_id}'
  _GROUPSERVICE.methods_by_name['List']._options = None
  _GROUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/organization-manager/v1/groups'
  _GROUPSERVICE.methods_by_name['Create']._options = None
  _GROUPSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\034\n\023CreateGroupMetadata\022\005Group\202\323\344\223\002$\"\037/organization-manager/v1/groups:\001*'
  _GROUPSERVICE.methods_by_name['Update']._options = None
  _GROUPSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\034\n\023UpdateGroupMetadata\022\005Group\202\323\344\223\002/2*/organization-manager/v1/groups/{group_id}:\001*'
  _GROUPSERVICE.methods_by_name['Delete']._options = None
  _GROUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002,**/organization-manager/v1/groups/{group_id}'
  _GROUPSERVICE.methods_by_name['ListOperations']._options = None
  _GROUPSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0027\0225/organization-manager/v1/groups/{group_id}/operations'
  _GROUPSERVICE.methods_by_name['ListMembers']._options = None
  _GROUPSERVICE.methods_by_name['ListMembers']._serialized_options = b'\202\323\344\223\0028\0226/organization-manager/v1/groups/{group_id}:listMembers'
  _GROUPSERVICE.methods_by_name['UpdateMembers']._options = None
  _GROUPSERVICE.methods_by_name['UpdateMembers']._serialized_options = b'\262\322*3\n\032UpdateGroupMembersMetadata\022\025google.protobuf.Empty\202\323\344\223\002=\"8/organization-manager/v1/groups/{group_id}:updateMembers:\001*'
  _GROUPSERVICE.methods_by_name['ListAccessBindings']._options = None
  _GROUPSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002B\022@/organization-manager/v1/groups/{resource_id}:listAccessBindings'
  _GROUPSERVICE.methods_by_name['SetAccessBindings']._options = None
  _GROUPSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002D\"?/organization-manager/v1/groups/{resource_id}:setAccessBindings:\001*'
  _GROUPSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _GROUPSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002G\"B/organization-manager/v1/groups/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETGROUPREQUEST']._serialized_start=348
  _globals['_GETGROUPREQUEST']._serialized_end=397
  _globals['_LISTGROUPSREQUEST']._serialized_start=400
  _globals['_LISTGROUPSREQUEST']._serialized_end=549
  _globals['_LISTGROUPSRESPONSE']._serialized_start=551
  _globals['_LISTGROUPSRESPONSE']._serialized_end=656
  _globals['_CREATEGROUPREQUEST']._serialized_start=659
  _globals['_CREATEGROUPREQUEST']._serialized_end=805
  _globals['_CREATEGROUPMETADATA']._serialized_start=807
  _globals['_CREATEGROUPMETADATA']._serialized_end=846
  _globals['_UPDATEGROUPREQUEST']._serialized_start=849
  _globals['_UPDATEGROUPREQUEST']._serialized_end=1034
  _globals['_UPDATEGROUPMETADATA']._serialized_start=1036
  _globals['_UPDATEGROUPMETADATA']._serialized_end=1075
  _globals['_DELETEGROUPREQUEST']._serialized_start=1077
  _globals['_DELETEGROUPREQUEST']._serialized_end=1129
  _globals['_DELETEGROUPMETADATA']._serialized_start=1131
  _globals['_DELETEGROUPMETADATA']._serialized_end=1170
  _globals['_LISTGROUPOPERATIONSREQUEST']._serialized_start=1172
  _globals['_LISTGROUPOPERATIONSREQUEST']._serialized_end=1295
  _globals['_LISTGROUPOPERATIONSRESPONSE']._serialized_start=1297
  _globals['_LISTGROUPOPERATIONSRESPONSE']._serialized_end=1406
  _globals['_LISTGROUPMEMBERSREQUEST']._serialized_start=1408
  _globals['_LISTGROUPMEMBERSREQUEST']._serialized_end=1528
  _globals['_LISTGROUPMEMBERSRESPONSE']._serialized_start=1530
  _globals['_LISTGROUPMEMBERSRESPONSE']._serialized_end=1648
  _globals['_GROUPMEMBER']._serialized_start=1650
  _globals['_GROUPMEMBER']._serialized_end=1705
  _globals['_UPDATEGROUPMEMBERSREQUEST']._serialized_start=1708
  _globals['_UPDATEGROUPMEMBERSREQUEST']._serialized_end=1852
  _globals['_UPDATEGROUPMEMBERSMETADATA']._serialized_start=1854
  _globals['_UPDATEGROUPMEMBERSMETADATA']._serialized_end=1900
  _globals['_MEMBERDELTA']._serialized_start=1903
  _globals['_MEMBERDELTA']._serialized_end=2103
  _globals['_MEMBERDELTA_MEMBERACTION']._serialized_start=2037
  _globals['_MEMBERDELTA_MEMBERACTION']._serialized_end=2103
  _globals['_GROUPSERVICE']._serialized_start=2106
  _globals['_GROUPSERVICE']._serialized_end=4392
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/service_account_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iam.v1 import service_account_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_service__account__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/iam/v1/service_account_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a)yandex/cloud/iam/v1/service_account.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"D\n\x18GetServiceAccountRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x98\x01\n\x1aListServiceAccountsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"u\n\x1bListServiceAccountsResponse\x12=\n\x10service_accounts\x18\x01 \x03(\x0b\x32#.yandex.cloud.iam.v1.ServiceAccount\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xce\x02\n\x1b\x43reateServiceAccountRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x04name\x18\x02 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x89\x01\n\x06labels\x18\x04 \x03(\x0b\x32<.yandex.cloud.iam.v1.CreateServiceAccountRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x1c\x43reateServiceAccountMetadata\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\"\x88\x03\n\x1bUpdateServiceAccountRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x33\n\x04name\x18\x03 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x89\x01\n\x06labels\x18\x05 \x03(\x0b\x32<.yandex.cloud.iam.v1.UpdateServiceAccountRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x1cUpdateServiceAccountMetadata\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\"G\n\x1b\x44\x65leteServiceAccountRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\":\n\x1c\x44\x65leteServiceAccountMetadata\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\"\x8e\x01\n#ListServiceAccountOperationsRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"v\n$ListServiceAccountOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x87\x0e\n\x15ServiceAccountService\x12\x8f\x01\n\x03Get\x12-.yandex.cloud.iam.v1.GetServiceAccountRequest\x1a#.yandex.cloud.iam.v1.ServiceAccount\"4\x82\xd3\xe4\x93\x02.\x12,/iam/v1/serviceAccounts/{service_account_id}\x12\x8a\x01\n\x04List\x12/.yandex.cloud.iam.v1.ListServiceAccountsRequest\x1a\x30.yandex.cloud.iam.v1.ListServiceAccountsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/iam/v1/serviceAccounts\x12\xb3\x01\n\x06\x43reate\x12\x30.yandex.cloud.iam.v1.CreateServiceAccountRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*.\n\x1c\x43reateServiceAccountMetadata\x12\x0eServiceAccount\x82\xd3\xe4\x93\x02\x1c\"\x17/iam/v1/serviceAccounts:\x01*\x12\xc8\x01\n\x06Update\x12\x30.yandex.cloud.iam.v1.UpdateServiceAccountRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*.\n\x1cUpdateServiceAccountMetadata\x12\x0eServiceAccount\x82\xd3\xe4\x93\x02\x31\x32,/iam/v1/serviceAccounts/{service_account_id}:\x01*\x12\xcc\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.iam.v1.DeleteServiceAccountRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*5\n\x1c\x44\x65leteServiceAccountMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02.*,/iam/v1/serviceAccounts/{service_account_id}\x12\xb7\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/iam/v1/serviceAccounts/{resource_id}:listAccessBindings\x12\xf6\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02<\"7/iam/v1/serviceAccounts/{resource_id}:setAccessBindings:\x01*\x12\x82\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x94\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02?\":/iam/v1/serviceAccounts/{resource_id}:updateAccessBindings:\x01*\x12\xc6\x01\n\x0eListOperations\x12\x38.yandex.cloud.iam.v1.ListServiceAccountOperationsRequest\x1a\x39.yandex.cloud.iam.v1.ListServiceAccountOperationsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/iam/v1/serviceAccounts/{service_account_id}/operationsBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.service_account_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _GETSERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._options = None
  _GETSERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSERVICEACCOUNTSREQUEST.fields_by_name['folder_id']._options = None
  _LISTSERVICEACCOUNTSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSERVICEACCOUNTSREQUEST.fields_by_name['page_size']._options = None
  _LISTSERVICEACCOUNTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSERVICEACCOUNTSREQUEST.fields_by_name['page_token']._options = None
  _LISTSERVICEACCOUNTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _LISTSERVICEACCOUNTSREQUEST.fields_by_name['filter']._options = None
  _LISTSERVICEACCOUNTSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATESERVICEACCOUNTREQUEST_LABELSENTRY._options = None
  _CREATESERVICEACCOUNTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['folder_id']._options = None
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['name']._options = None
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['description']._options = None
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['labels']._options = None
  _CREATESERVICEACCOUNTREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATESERVICEACCOUNTREQUEST_LABELSENTRY._options = None
  _UPDATESERVICEACCOUNTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._options = None
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['name']._options = None
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['description']._options = None
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['labels']._options = None
  _UPDATESERVICEACCOUNTREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _DELETESERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._options = None
  _DELETESERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSERVICEACCOUNTOPERATIONSREQUEST.fields_by_name['service_account_id']._options = None
  _LISTSERVICEACCOUNTOPERATIONSREQUEST.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSERVICEACCOUNTOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTSERVICEACCOUNTOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSERVICEACCOUNTOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTSERVICEACCOUNTOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _SERVICEACCOUNTSERVICE.methods_by_name['Get']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002.\022,/iam/v1/serviceAccounts/{service_account_id}'
  _SERVICEACCOUNTSERVICE.methods_by_name['List']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/iam/v1/serviceAccounts'
  _SERVICEACCOUNTSERVICE.methods_by_name['Create']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*.\n\034CreateServiceAccountMetadata\022\016ServiceAccount\202\323\344\223\002\034\"\027/iam/v1/serviceAccounts:\001*'
  _SERVICEACCOUNTSERVICE.methods_by_name['Update']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*.\n\034UpdateServiceAccountMetadata\022\016ServiceAccount\202\323\344\223\00212,/iam/v1/serviceAccounts/{service_account_id}:\001*'
  _SERVICEACCOUNTSERVICE.methods_by_name['Delete']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*5\n\034DeleteServiceAccountMetadata\022\025google.protobuf.Empty\202\323\344\223\002.*,/iam/v1/serviceAccounts/{service_account_id}'
  _SERVICEACCOUNTSERVICE.methods_by_name['ListAccessBindings']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002:\0228/iam/v1/serviceAccounts/{resource_id}:listAccessBindings'
  _SERVICEACCOUNTSERVICE.methods_by_name['SetAccessBindings']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002<\"7/iam/v1/serviceAccounts/{resource_id}:setAccessBindings:\001*'
  _SERVICEACCOUNTSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002?\":/iam/v1/serviceAccounts/{resource_id}:updateAccessBindings:\001*'
  _SERVICEACCOUNTSERVICE.methods_by_name['ListOperations']._options = None
  _SERVICEACCOUNTSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0029\0227/iam/v1/serviceAccounts/{service_account_id}/operations'
  _globals['_GETSERVICEACCOUNTREQUEST']._serialized_start=320
  _globals['_GETSERVICEACCOUNTREQUEST']._serialized_end=388
  _globals['_LISTSERVICEACCOUNTSREQUEST']._serialized_start=391
  _globals['_LISTSERVICEACCOUNTSREQUEST']._serialized_end=543
  _globals['_LISTSERVICEACCOUNTSRESPONSE']._serialized_start=545
  _globals['_LISTSERVICEACCOUNTSRESPONSE']._serialized_end=662
  _globals['_CREATESERVICEACCOUNTREQUEST']._serialized_start=665
  _globals['_CREATESERVICEACCOUNTREQUEST']._serialized_end=999
  _globals['_CREATESERVICEACCOUNTREQUEST_LABELSENTRY']._serialized_start=954
  _globals['_CREATESERVICEACCOUNTREQUEST_LABELSENTRY']._serialized_end=999
  _globals['_CREATESERVICEACCOUNTMETADATA']._serialized_start=1001
  _globals['_CREATESERVICEACCOUNTMETADATA']._serialized_end=1059
  _globals['_UPDATESERVICEACCOUNTREQUEST']._serialized_start=1062
  _globals['_UPDATESERVICEACCOUNTREQUEST']._serialized_end=1454
  _globals['_UPDATESERVICEACCOUNTREQUEST_LABELSENTRY']._serialized_start=954
  _globals['_UPDATESERVICEACCOUNTREQUEST_LABELSENTRY']._serialized_end=999
  _globals['_UPDATESERVICEACCOUNTMETADATA']._serialized_start=1456
  _globals['_UPDATESERVICEACCOUNTMETADATA']._serialized_end=1514
  _globals['_DELETESERVICEACCOUNTREQUEST']._serialized_start=1516
  _globals['_DELETESERVICEACCOUNTREQUEST']._serialized_end=1587
  _globals['_DELETESERVICEACCOUNTMETADATA']._serialized_start=1589
  _globals['_DELETESERVICEACCOUNTMETADATA']._serialized_end=1647
  _globals['_LISTSERVICEACCOUNTOPERATIONSREQUEST']._serialized_start=1650
  _globals['_LISTSERVICEACCOUNTOPERATIONSREQUEST']._serialized_end=1792
  _globals['_LISTSERVICEACCOUNTOPERATIONSRESPONSE']._serialized_start=1794
  _globals['_LISTSERVICEACCOUNTOPERATIONSRESPONSE']._serialized_end=1912
  _globals['_SERVICEACCOUNTSERVICE']._serialized_start=1915
  _globals['_SERVICEACCOUNTSERVICE']._serialized_end=3714
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.k8s.v1 import cluster_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_cluster__pb2
from yandex.cloud.k8s.v1 import node_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2
from yandex.cloud.k8s.v1 import node_group_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2
from yandex.cloud.k8s.v1 import version_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/k8s/v1/cluster_service.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a!yandex/cloud/k8s/v1/cluster.proto\x1a\x1eyandex/cloud/k8s/v1/node.proto\x1a$yandex/cloud/k8s/v1/node_group.proto\x1a!yandex/cloud/k8s/v1/version.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"-\n\x11GetClusterRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x88\x01\n\x13ListClustersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"_\n\x14ListClustersResponse\x12.\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.k8s.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"0\n\x14\x44\x65leteClusterRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\".\n\x12StopClusterRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"/\n\x13StartClusterRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xab\x05\n\x14UpdateClusterRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8a\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.k8s.v1.UpdateClusterRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12(\n\x14gateway_ipv4_address\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=15H\x00\x12:\n\x0bmaster_spec\x18\x07 \x01(\x0b\x32%.yandex.cloud.k8s.v1.MasterUpdateSpec\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x12\x1f\n\x17node_service_account_id\x18\x08 \x01(\t\x12:\n\x0enetwork_policy\x18\n \x01(\x0b\x32\".yandex.cloud.k8s.v1.NetworkPolicy\x12\x45\n\x14ip_allocation_policy\x18\x0b \x01(\x0b\x32\'.yandex.cloud.k8s.v1.IPAllocationPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10internet_gateway\"\xa3\x02\n\x10MasterUpdateSpec\x12\x37\n\x07version\x18\x01 \x01(\x0b\x32&.yandex.cloud.k8s.v1.UpdateVersionSpec\x12H\n\x12maintenance_policy\x18\x02 \x01(\x0b\x32,.yandex.cloud.k8s.v1.MasterMaintenancePolicy\x12\x1a\n\x12security_group_ids\x18\x03 \x03(\t\x12:\n\x0emaster_logging\x18\x04 \x01(\x0b\x32\".yandex.cloud.k8s.v1.MasterLogging\x12\x34\n\tlocations\x18\x05 \x03(\x0b\x32!.yandex.cloud.k8s.v1.LocationSpec\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xd4\x06\n\x14\x43reateClusterRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8a\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x35.yandex.cloud.k8s.v1.CreateClusterRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x18\n\nnetwork_id\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12:\n\x0bmaster_spec\x18\x06 \x01(\x0b\x32\x1f.yandex.cloud.k8s.v1.MasterSpecB\x04\xe8\xc7\x31\x01\x12\x45\n\x14ip_allocation_policy\x18\x07 \x01(\x0b\x32\'.yandex.cloud.k8s.v1.IPAllocationPolicy\x12\x1e\n\x14gateway_ipv4_address\x18\x08 \x01(\tH\x00\x12 \n\x12service_account_id\x18\t \x01(\tB\x04\xe8\xc7\x31\x01\x12%\n\x17node_service_account_id\x18\n \x01(\tB\x04\xe8\xc7\x31\x01\x12<\n\x0frelease_channel\x18\x0b \x01(\x0e\x32#.yandex.cloud.k8s.v1.ReleaseChannel\x12:\n\x0enetwork_policy\x18\x0c \x01(\x0b\x32\".yandex.cloud.k8s.v1.NetworkPolicy\x12\x36\n\x0ckms_provider\x18\r \x01(\x0b\x32 .yandex.cloud.k8s.v1.KMSProvider\x12-\n\x06\x63ilium\x18\x0e \x01(\x0b\x32\x1b.yandex.cloud.k8s.v1.CiliumH\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10internet_gatewayB\x18\n\x16network_implementation\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"/\n\x19\x41utoUpgradeMasterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\x92\x01\n\x1cListClusterOperationsRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"o\n\x1dListClusterOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x92\x01\n\x1cListClusterNodeGroupsRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"m\n\x1dListClusterNodeGroupsResponse\x12\x33\n\x0bnode_groups\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.k8s.v1.NodeGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"q\n\x17ListClusterNodesRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"]\n\x18ListClusterNodesResponse\x12(\n\x05nodes\x18\x01 \x03(\x0b\x32\x19.yandex.cloud.k8s.v1.Node\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd4\x04\n\nMasterSpec\x12\x41\n\x11zonal_master_spec\x18\x01 \x01(\x0b\x32$.yandex.cloud.k8s.v1.ZonalMasterSpecH\x00\x12G\n\x14regional_master_spec\x18\x02 \x01(\x0b\x32\'.yandex.cloud.k8s.v1.RegionalMasterSpecH\x00\x12\x34\n\tlocations\x18\x08 \x03(\x0b\x32!.yandex.cloud.k8s.v1.LocationSpec\x12$\n\x11\x65tcd_cluster_size\x18\t \x01(\x03\x42\t\xfa\xc7\x31\x05\x30,1,3\x12J\n\x18\x65xternal_v4_address_spec\x18\n \x01(\x0b\x32(.yandex.cloud.k8s.v1.ExternalAddressSpec\x12J\n\x18\x65xternal_v6_address_spec\x18\x0b \x01(\x0b\x32(.yandex.cloud.k8s.v1.ExternalAddressSpec\x12\x0f\n\x07version\x18\x03 \x01(\t\x12H\n\x12maintenance_policy\x18\x04 \x01(\x0b\x32,.yandex.cloud.k8s.v1.MasterMaintenancePolicy\x12\x1a\n\x12security_group_ids\x18\x06 \x03(\t\x12:\n\x0emaster_logging\x18\x07 \x01(\x0b\x32\".yandex.cloud.k8s.v1.MasterLoggingB\r\n\x0bmaster_typeJ\x04\x08\x05\x10\x06\"\xc0\x01\n\x0fZonalMasterSpec\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12J\n\x18internal_v4_address_spec\x18\x02 \x01(\x0b\x32(.yandex.cloud.k8s.v1.InternalAddressSpec\x12J\n\x18\x65xternal_v4_address_spec\x18\x03 \x01(\x0b\x32(.yandex.cloud.k8s.v1.ExternalAddressSpec\"\xfd\x01\n\x12RegionalMasterSpec\x12\x17\n\tregion_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x36\n\tlocations\x18\x02 \x03(\x0b\x32#.yandex.cloud.k8s.v1.MasterLocation\x12J\n\x18\x65xternal_v4_address_spec\x18\x03 \x01(\x0b\x32(.yandex.cloud.k8s.v1.ExternalAddressSpec\x12J\n\x18\x65xternal_v6_address_spec\x18\x04 \x01(\x0b\x32(.yandex.cloud.k8s.v1.ExternalAddressSpec\"(\n\x13InternalAddressSpec\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"&\n\x13\x45xternalAddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"s\n\x0eMasterLocation\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12J\n\x18internal_v4_address_spec\x18\x02 \x01(\x0b\x32(.yandex.cloud.k8s.v1.InternalAddressSpec\"8\n\x0cLocationSpec\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tsubnet_id\x18\x02 \x01(\t2\xc6\r\n\x0e\x43lusterService\x12\x81\x01\n\x03Get\x12&.yandex.cloud.k8s.v1.GetClusterRequest\x1a\x1c.yandex.cloud.k8s.v1.Cluster\"4\x82\xd3\xe4\x93\x02.\x12,/managed-kubernetes/v1/clusters/{cluster_id}\x12\x84\x01\n\x04List\x12(.yandex.cloud.k8s.v1.ListClustersRequest\x1a).yandex.cloud.k8s.v1.ListClustersResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/managed-kubernetes/v1/clusters\x12\xa6\x01\n\x06\x43reate\x12).yandex.cloud.k8s.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02$\"\x1f/managed-kubernetes/v1/clusters:\x01*\x12\xb3\x01\n\x06Update\x12).yandex.cloud.k8s.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x31\x32,/managed-kubernetes/v1/clusters/{cluster_id}:\x01*\x12\xbe\x01\n\x06\x44\x65lete\x12).yandex.cloud.k8s.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02.*,/managed-kubernetes/v1/clusters/{cluster_id}\x12\xb2\x01\n\x04Stop\x12\'.yandex.cloud.k8s.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x36\"1/managed-kubernetes/v1/clusters/{cluster_id}:stop:\x01*\x12\xb6\x01\n\x05Start\x12(.yandex.cloud.k8s.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x37\"2/managed-kubernetes/v1/clusters/{cluster_id}:start:\x01*\x12\xb8\x01\n\x0eListNodeGroups\x12\x31.yandex.cloud.k8s.v1.ListClusterNodeGroupsRequest\x1a\x32.yandex.cloud.k8s.v1.ListClusterNodeGroupsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-kubernetes/v1/clusters/{cluster_id}/nodeGroups\x12\xb8\x01\n\x0eListOperations\x12\x31.yandex.cloud.k8s.v1.ListClusterOperationsRequest\x1a\x32.yandex.cloud.k8s.v1.ListClusterOperationsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-kubernetes/v1/clusters/{cluster_id}/operations\x12\xa4\x01\n\tListNodes\x12,.yandex.cloud.k8s.v1.ListClusterNodesRequest\x1a-.yandex.cloud.k8s.v1.ListClusterNodesResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-kubernetes/v1/clusters/{cluster_id}/nodesBV\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s'
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STOPCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _STARTCLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _UPDATECLUSTERREQUEST_LABELSENTRY._options = None
  _UPDATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _UPDATECLUSTERREQUEST.fields_by_name['name']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATECLUSTERREQUEST.fields_by_name['description']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATECLUSTERREQUEST.fields_by_name['gateway_ipv4_address']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['gateway_ipv4_address']._serialized_options = b'\212\3101\004<=15'
  _CREATECLUSTERREQUEST_LABELSENTRY._options = None
  _CREATECLUSTERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATECLUSTERREQUEST.fields_by_name['name']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATECLUSTERREQUEST.fields_by_name['description']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECLUSTERREQUEST.fields_by_name['labels']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['network_id']._serialized_options = b'\350\3071\001'
  _CREATECLUSTERREQUEST.fields_by_name['master_spec']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['master_spec']._serialized_options = b'\350\3071\001'
  _CREATECLUSTERREQUEST.fields_by_name['service_account_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001'
  _CREATECLUSTERREQUEST.fields_by_name['node_service_account_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['node_service_account_id']._serialized_options = b'\350\3071\001'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTEROPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTCLUSTERNODEGROUPSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERNODEGROUPSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _LISTCLUSTERNODEGROUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERNODEGROUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTERNODEGROUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERNODEGROUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCLUSTERNODEGROUPSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERNODEGROUPSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTCLUSTERNODESREQUEST.fields_by_name['cluster_id']._options = None
  _LISTCLUSTERNODESREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _LISTCLUSTERNODESREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERNODESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTCLUSTERNODESREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERNODESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _MASTERSPEC.fields_by_name['etcd_cluster_size']._options = None
  _MASTERSPEC.fields_by_name['etcd_cluster_size']._serialized_options = b'\372\3071\0050,1,3'
  _ZONALMASTERSPEC.fields_by_name['zone_id']._options = None
  _ZONALMASTERSPEC.fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _REGIONALMASTERSPEC.fields_by_name['region_id']._options = None
  _REGIONALMASTERSPEC.fields_by_name['region_id']._serialized_options = b'\350\3071\001'
  _MASTERLOCATION.fields_by_name['zone_id']._options = None
  _MASTERLOCATION.fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _LOCATIONSPEC.fields_by_name['zone_id']._options = None
  _LOCATIONSPEC.fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _CLUSTERSERVICE.methods_by_name['Get']._options = None
  _CLUSTERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002.\022,/managed-kubernetes/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['List']._options = None
  _CLUSTERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/managed-kubernetes/v1/clusters'
  _CLUSTERSERVICE.methods_by_name['Create']._options = None
  _CLUSTERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002$\"\037/managed-kubernetes/v1/clusters:\001*'
  _CLUSTERSERVICE.methods_by_name['Update']._options = None
  _CLUSTERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\00212,/managed-kubernetes/v1/clusters/{cluster_id}:\001*'
  _CLUSTERSERVICE.methods_by_name['Delete']._options = None
  _CLUSTERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002.*,/managed-kubernetes/v1/clusters/{cluster_id}'
  _CLUSTERSERVICE.methods_by_name['Stop']._options = None
  _CLUSTERSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\0026\"1/managed-kubernetes/v1/clusters/{cluster_id}:stop:\001*'
  _CLUSTERSERVICE.methods_by_name['Start']._options = None
  _CLUSTERSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\0027\"2/managed-kubernetes/v1/clusters/{cluster_id}:start:\001*'
  _CLUSTERSERVICE.methods_by_name['ListNodeGroups']._options = None
  _CLUSTERSERVICE.methods_by_name['ListNodeGroups']._serialized_options = b'\202\323\344\223\0029\0227/managed-kubernetes/v1/clusters/{cluster_id}/nodeGroups'
  _CLUSTERSERVICE.methods_by_name['ListOperations']._options = None
  _CLUSTERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0029\0227/managed-kubernetes/v1/clusters/{cluster_id}/operations'
  _CLUSTERSERVICE.methods_by_name['ListNodes']._options = None
  _CLUSTERSERVICE.methods_by_name['ListNodes']._serialized_options = b'\202\323\344\223\0024\0222/managed-kubernetes/v1/clusters/{cluster_id}/nodes'
  _globals['_GETCLUSTERREQUEST']._serialized_start=375
  _globals['_GETCLUSTERREQUEST']._serialized_end=420
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=423
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=559
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=561
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=656
  _globals['_DELETECLUSTERREQUEST']._serialized_start=658
  _globals['_DELETECLUSTERREQUEST']._serialized_end=706
  _globals['_DELETECLUSTERMETADATA']._serialized_start=708
  _globals['_DELETECLUSTERMETADATA']._serialized_end=751
  _globals['_STOPCLUSTERREQUEST']._serialized_start=753
  _globals['_STOPCLUSTERREQUEST']._serialized_end=799
  _globals['_STOPCLUSTERMETADATA']._serialized_start=801
  _globals['_STOPCLUSTERMETADATA']._serialized_end=842
  _globals['_STARTCLUSTERREQUEST']._serialized_start=844
  _globals['_STARTCLUSTERREQUEST']._serialized_end=891
  _globals['_STARTCLUSTERMETADATA']._serialized_start=893
  _globals['_STARTCLUSTERMETADATA']._serialized_end=935
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=938
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=1621
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1556
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1601
  _globals['_MASTERUPDATESPEC']._serialized_start=1624
  _globals['_MASTERUPDATESPEC']._serialized_end=1915
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=1917
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=1960
  _globals['_CREATECLUSTERREQUEST']._serialized_start=1963
  _globals['_CREATECLUSTERREQUEST']._serialized_end=2815
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=1556
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=1601
  _globals['_CREATECLUSTERMETADATA']._serialized_start=2817
  _globals['_CREATECLUSTERMETADATA']._serialized_end=2860
  _globals['_AUTOUPGRADEMASTERMETADATA']._serialized_start=2862
  _globals['_AUTOUPGRADEMASTERMETADATA']._serialized_end=2909
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=2912
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=3058
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=3060
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=3171
  _globals['_LISTCLUSTERNODEGROUPSREQUEST']._serialized_start=3174
  _globals['_LISTCLUSTERNODEGROUPSREQUEST']._serialized_end=3320
  _globals['_LISTCLUSTERNODEGROUPSRESPONSE']._serialized_start=3322
  _globals['_LISTCLUSTERNODEGROUPSRESPONSE']._serialized_end=3431
  _globals['_LISTCLUSTERNODESREQUEST']._serialized_start=3433
  _globals['_LISTCLUSTERNODESREQUEST']._serialized_end=3546
  _globals['_LISTCLUSTERNODESRESPONSE']._serialized_start=3548
  _globals['_LISTCLUSTERNODESRESPONSE']._serialized_end=3641
  _globals['_MASTERSPEC']._serialized_start=3644
  _globals['_MASTERSPEC']._serialized_end=4240
  _globals['_ZONALMASTERSPEC']._serialized_start=4243
  _globals['_ZONALMASTERSPEC']._serialized_end=4435
  _globals['_REGIONALMASTERSPEC']._serialized_start=4438
  _globals['_REGIONALMASTERSPEC']._serialized_end=4691
  _globals['_INTERNALADDRESSSPEC']._serialized_start=4693
  _globals['_INTERNALADDRESSSPEC']._serialized_end=4733
  _globals['_EXTERNALADDRESSSPEC']._serialized_start=4735
  _globals['_EXTERNALADDRESSSPEC']._serialized_end=4773
  _globals['_MASTERLOCATION']._serialized_start=4775
  _globals['_MASTERLOCATION']._serialized_end=4890
  _globals['_LOCATIONSPEC']._serialized_start=4892
  _globals['_LOCATIONSPEC']._serialized_end=4948
  _globals['_CLUSTERSERVICE']._serialized_start=4951
  _globals['_CLUSTERSERVICE']._serialized_end=6685
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/key_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.iam.v1 import key_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_key__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/iam/v1/key_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1dyandex/cloud/iam/v1/key.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"]\n\rGetKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x1e.yandex.cloud.iam.v1.KeyFormat\"\xa6\x01\n\x0fListKeysRequest\x12.\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x1e.yandex.cloud.iam.v1.KeyFormat\x12$\n\x12service_account_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"S\n\x10ListKeysResponse\x12&\n\x04keys\x18\x01 \x03(\x0b\x32\x18.yandex.cloud.iam.v1.Key\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc3\x01\n\x10\x43reateKeyRequest\x12$\n\x12service_account_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12.\n\x06\x66ormat\x18\x03 \x01(\x0e\x32\x1e.yandex.cloud.iam.v1.KeyFormat\x12\x39\n\rkey_algorithm\x18\x04 \x01(\x0e\x32\".yandex.cloud.iam.v1.Key.Algorithm\"O\n\x11\x43reateKeyResponse\x12%\n\x03key\x18\x01 \x01(\x0b\x32\x18.yandex.cloud.iam.v1.Key\x12\x13\n\x0bprivate_key\x18\x02 \x01(\t\"\x81\x01\n\x10UpdateKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"#\n\x11UpdateKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"0\n\x10\x44\x65leteKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"#\n\x11\x44\x65leteKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"w\n\x18ListKeyOperationsRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"k\n\x19ListKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*\x19\n\tKeyFormat\x12\x0c\n\x08PEM_FILE\x10\x00\x32\x9e\x06\n\nKeyService\x12\x62\n\x03Get\x12\".yandex.cloud.iam.v1.GetKeyRequest\x1a\x18.yandex.cloud.iam.v1.Key\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/iam/v1/keys/{key_id}\x12i\n\x04List\x12$.yandex.cloud.iam.v1.ListKeysRequest\x1a%.yandex.cloud.iam.v1.ListKeysResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/iam/v1/keys\x12p\n\x06\x43reate\x12%.yandex.cloud.iam.v1.CreateKeyRequest\x1a&.yandex.cloud.iam.v1.CreateKeyResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/iam/v1/keys:\x01*\x12\x90\x01\n\x06Update\x12%.yandex.cloud.iam.v1.UpdateKeyRequest\x1a!.yandex.cloud.operation.Operation\"<\xb2\xd2*\x18\n\x11UpdateKeyMetadata\x12\x03Key\x82\xd3\xe4\x93\x02\x1a\x32\x15/iam/v1/keys/{key_id}:\x01*\x12\x9f\x01\n\x06\x44\x65lete\x12%.yandex.cloud.iam.v1.DeleteKeyRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2**\n\x11\x44\x65leteKeyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x17*\x15/iam/v1/keys/{key_id}\x12\x99\x01\n\x0eListOperations\x12-.yandex.cloud.iam.v1.ListKeyOperationsRequest\x1a..yandex.cloud.iam.v1.ListKeyOperationsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /iam/v1/keys/{key_id}/operationsBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.key_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _GETKEYREQUEST.fields_by_name['key_id']._options = None
  _GETKEYREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTKEYSREQUEST.fields_by_name['service_account_id']._options = None
  _LISTKEYSREQUEST.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _LISTKEYSREQUEST.fields_by_name['page_size']._options = None
  _LISTKEYSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTKEYSREQUEST.fields_by_name['page_token']._options = None
  _LISTKEYSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _CREATEKEYREQUEST.fields_by_name['service_account_id']._options = None
  _CREATEKEYREQUEST.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _CREATEKEYREQUEST.fields_by_name['description']._options = None
  _CREATEKEYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEKEYREQUEST.fields_by_name['key_id']._options = None
  _UPDATEKEYREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEKEYREQUEST.fields_by_name['description']._options = None
  _UPDATEKEYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _DELETEKEYREQUEST.fields_by_name['key_id']._options = None
  _DELETEKEYREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTKEYOPERATIONSREQUEST.fields_by_name['key_id']._options = None
  _LISTKEYOPERATIONSREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTKEYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTKEYOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTKEYOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTKEYOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _KEYSERVICE.methods_by_name['Get']._options = None
  _KEYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\027\022\025/iam/v1/keys/{key_id}'
  _KEYSERVICE.methods_by_name['List']._options = None
  _KEYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\016\022\014/iam/v1/keys'
  _KEYSERVICE.methods_by_name['Create']._options = None
  _KEYSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\021\"\014/iam/v1/keys:\001*'
  _KEYSERVICE.methods_by_name['Update']._options = None
  _KEYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\030\n\021UpdateKeyMetadata\022\003Key\202\323\344\223\002\0322\025/iam/v1/keys/{key_id}:\001*'
  _KEYSERVICE.methods_by_name['Delete']._options = None
  _KEYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322**\n\021DeleteKeyMetadata\022\025google.protobuf.Empty\202\323\344\223\002\027*\025/iam/v1/keys/{key_id}'
  _KEYSERVICE.methods_by_name['ListOperations']._options = None
  _KEYSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002\"\022 /iam/v1/keys/{key_id}/operations'
  _globals['_KEYFORMAT']._serialized_start=1376
  _globals['_KEYFORMAT']._serialized_end=1401
  _globals['_GETKEYREQUEST']._serialized_start=262
  _globals['_GETKEYREQUEST']._serialized_end=355
  _globals['_LISTKEYSREQUEST']._serialized_start=358
  _globals['_LISTKEYSREQUEST']._serialized_end=524
  _globals['_LISTKEYSRESPONSE']._serialized_start=526
  _globals['_LISTKEYSRESPONSE']._serialized_end=609
  _globals['_CREATEKEYREQUEST']._serialized_start=612
  _globals['_CREATEKEYREQUEST']._serialized_end=807
  _globals['_CREATEKEYRESPONSE']._serialized_start=809
  _globals['_CREATEKEYRESPONSE']._serialized_end=888
  _globals['_UPDATEKEYREQUEST']._serialized_start=891
  _globals['_UPDATEKEYREQUEST']._serialized_end=1020
  _globals['_UPDATEKEYMETADATA']._serialized_start=1022
  _globals['_UPDATEKEYMETADATA']._serialized_end=1057
  _globals['_DELETEKEYREQUEST']._serialized_start=1059
  _globals['_DELETEKEYREQUEST']._serialized_end=1107
  _globals['_DELETEKEYMETADATA']._serialized_start=1109
  _globals['_DELETEKEYMETADATA']._serialized_end=1144
  _globals['_LISTKEYOPERATIONSREQUEST']._serialized_start=1146
  _globals['_LISTKEYOPERATIONSREQUEST']._serialized_end=1265
  _globals['_LISTKEYOPERATIONSRESPONSE']._serialized_start=1267
  _globals['_LISTKEYOPERATIONSRESPONSE']._serialized_end=1374
  _globals['_KEYSERVICE']._serialized_start=1404
  _globals['_KEYSERVICE']._serialized_end=2202
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/test/imbalance_point.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/loadtesting/api/v1/test/imbalance_point.proto\x12$yandex.cloud.loadtesting.api.v1.test\x1a\x1fgoogle/protobuf/timestamp.proto\"E\n\x0eImbalancePoint\x12&\n\x02\x61t\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03rps\x18\x02 \x01(\x03\x42y\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test.imbalance_point_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;test'
  _globals['_IMBALANCEPOINT']._serialized_start=133
  _globals['_IMBALANCEPOINT']._serialized_end=202
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/mdb/kafka/v1/user.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1dyandex/cloud/validation.proto\"d\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12:\n\x0bpermissions\x18\x03 \x03(\x0b\x32%.yandex.cloud.mdb.kafka.v1.Permission\"\x95\x01\n\x08UserSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x05\x31-256\x12\x1f\n\x08password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12:\n\x0bpermissions\x18\x03 \x03(\x0b\x32%.yandex.cloud.mdb.kafka.v1.Permission\"\xf1\x01\n\nPermission\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12>\n\x04role\x18\x02 \x01(\x0e\x32\x30.yandex.cloud.mdb.kafka.v1.Permission.AccessRole\x12\x13\n\x0b\x61llow_hosts\x18\x04 \x03(\t\"t\n\nAccessRole\x12\x1b\n\x17\x41\x43\x43\x45SS_ROLE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x41\x43\x43\x45SS_ROLE_PRODUCER\x10\x01\x12\x18\n\x14\x41\x43\x43\x45SS_ROLE_CONSUMER\x10\x02\x12\x15\n\x11\x41\x43\x43\x45SS_ROLE_ADMIN\x10\x03J\x04\x08\x03\x10\x04\x42\x64\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _USERSPEC.fields_by_name['name']._options = None
  _USERSPEC.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\0051-256'
  _USERSPEC.fields_by_name['password']._options = None
  _USERSPEC.fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _globals['_USER']._serialized_start=98
  _globals['_USER']._serialized_end=198
  _globals['_USERSPEC']._serialized_start=201
  _globals['_USERSPEC']._serialized_end=350
  _globals['_PERMISSION']._serialized_start=353
  _globals['_PERMISSION']._serialized_end=594
  _globals['_PERMISSION_ACCESSROLE']._serialized_start=472
  _globals['_PERMISSION_ACCESSROLE']._serialized_end=588
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/greenplum/v1/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/mdb/greenplum/v1/config.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"\x90\x02\n\x16\x43onnectionPoolerConfig\x12L\n\x04mode\x18\x01 \x01(\x0e\x32>.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig.PoolMode\x12)\n\x04size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13\x63lient_idle_timeout\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"C\n\x08PoolMode\x12\x19\n\x15POOL_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\x0f\n\x0bTRANSACTION\x10\x02\"O\n\x19\x42\x61\x63kgroundActivityStartAt\x12\x17\n\x05hours\x18\x01 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-23\x12\x19\n\x07minutes\x18\x02 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-59\"_\n\nTableSizes\x12Q\n\x06starts\x18\x01 \x03(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.BackgroundActivityStartAtB\x07\x82\xc8\x31\x03<=4\"\xe6\x01\n\x10\x41nalyzeAndVacuum\x12G\n\x05start\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.BackgroundActivityStartAt\x12\x44\n\x0f\x61nalyze_timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n7200-86399\x12\x43\n\x0evacuum_timeout\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n7200-86399\"\xa9\x01\n\x1a\x42\x61\x63kgroundActivitiesConfig\x12>\n\x0btable_sizes\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.greenplum.v1.TableSizes\x12K\n\x12\x61nalyze_and_vacuum\x18\x02 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.AnalyzeAndVacuum\"U\n\x16MasterSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"V\n\x17SegmentSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"\x96\x05\n\x10GreenplumConfig6\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\x12H\n$gp_add_column_inherits_table_setting\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xd3\x03\n\x13GreenplumConfig6_17\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xcf\x04\n\x13GreenplumConfig6_19\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\"\x99\x05\n\x13GreenplumConfig6_21\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\x12H\n$gp_add_column_inherits_table_setting\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x99\x05\n\x13GreenplumConfig6_22\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\x12H\n$gp_add_column_inherits_table_setting\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x81\x02\n\x16GreenplumConfigSet6_17\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17B\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17\"\x81\x02\n\x16GreenplumConfigSet6_19\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19B\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19\"\x81\x02\n\x16GreenplumConfigSet6_21\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_21B\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_21\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_21\"\x81\x02\n\x16GreenplumConfigSet6_22\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_22B\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_22\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_22\"\xf5\x01\n\x13GreenplumConfigSet6\x12O\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6B\x04\xe8\xc7\x31\x01\x12\x44\n\x0buser_config\x18\x02 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6\x12G\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6\"\x8d\x02\n\x19\x43onnectionPoolerConfigSet\x12U\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfigB\x04\xe8\xc7\x31\x01\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig*R\n\x0cLogStatement\x12\x1d\n\x19LOG_STATEMENT_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03\x44\x44L\x10\x02\x12\x07\n\x03MOD\x10\x03\x12\x07\n\x03\x41LL\x10\x04\x42p\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _BACKGROUNDACTIVITYSTARTAT.fields_by_name['hours']._options = None
  _BACKGROUNDACTIVITYSTARTAT.fields_by_name['hours']._serialized_options = b'\372\3071\0040-23'
  _BACKGROUNDACTIVITYSTARTAT.fields_by_name['minutes']._options = None
  _BACKGROUNDACTIVITYSTARTAT.fields_by_name['minutes']._serialized_options = b'\372\3071\0040-59'
  _TABLESIZES.fields_by_name['starts']._options = None
  _TABLESIZES.fields_by_name['starts']._serialized_options = b'\202\3101\003<=4'
  _ANALYZEANDVACUUM.fields_by_name['analyze_timeout']._options = None
  _ANALYZEANDVACUUM.fields_by_name['analyze_timeout']._serialized_options = b'\372\3071\n7200-86399'
  _ANALYZEANDVACUUM.fields_by_name['vacuum_timeout']._options = None
  _ANALYZEANDVACUUM.fields_by_name['vacuum_timeout']._serialized_options = b'\372\3071\n7200-86399'
  _GREENPLUMCONFIGSET6_17.fields_by_name['effective_config']._options = None
  _GREENPLUMCONFIGSET6_17.fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _GREENPLUMCONFIGSET6_19.fields_by_name['effective_config']._options = None
  _GREENPLUMCONFIGSET6_19.fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _GREENPLUMCONFIGSET6_21.fields_by_name['effective_config']._options = None
  _GREENPLUMCONFIGSET6_21.fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _GREENPLUMCONFIGSET6_22.fields_by_name['effective_config']._options = None
  _GREENPLUMCONFIGSET6_22.fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _GREENPLUMCONFIGSET6.fields_by_name['effective_config']._options = None
  _GREENPLUMCONFIGSET6.fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _CONNECTIONPOOLERCONFIGSET.fields_by_name['effective_config']._options = None
  _CONNECTIONPOOLERCONFIGSET.fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_LOGSTATEMENT']._serialized_start=5880
  _globals['_LOGSTATEMENT']._serialized_end=5962
  _globals['_RESOURCES']._serialized_start=140
  _globals['_RESOURCES']._serialized_end=220
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_start=223
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_end=495
  _globals['_CONNECTIONPOOLERCONFIG_POOLMODE']._serialized_start=428
  _globals['_CONNECTIONPOOLERCONFIG_POOLMODE']._serialized_end=495
  _globals['_BACKGROUNDACTIVITYSTARTAT']._serialized_start=497
  _globals['_BACKGROUNDACTIVITYSTARTAT']._serialized_end=576
  _globals['_TABLESIZES']._serialized_start=578
  _globals['_TABLESIZES']._serialized_end=673
  _globals['_ANALYZEANDVACUUM']._serialized_start=676
  _globals['_ANALYZEANDVACUUM']._serialized_end=906
  _globals['_BACKGROUNDACTIVITIESCONFIG']._serialized_start=909
  _globals['_BACKGROUNDACTIVITIESCONFIG']._serialized_end=1078
  _globals['_MASTERSUBCLUSTERCONFIG']._serialized_start=1080
  _globals['_MASTERSUBCLUSTERCONFIG']._serialized_end=1165
  _globals['_SEGMENTSUBCLUSTERCONFIG']._serialized_start=1167
  _globals['_SEGMENTSUBCLUSTERCONFIG']._serialized_end=1253
  _globals['_GREENPLUMCONFIG6']._serialized_start=1256
  _globals['_GREENPLUMCONFIG6']._serialized_end=1918
  _globals['_GREENPLUMCONFIG6_17']._serialized_start=1921
  _globals['_GREENPLUMCONFIG6_17']._serialized_end=2388
  _globals['_GREENPLUMCONFIG6_19']._serialized_start=2391
  _globals['_GREENPLUMCONFIG6_19']._serialized_end=2982
  _globals['_GREENPLUMCONFIG6_21']._serialized_start=2985
  _globals['_GREENPLUMCONFIG6_21']._serialized_end=3650
  _globals['_GREENPLUMCONFIG6_22']._serialized_start=3653
  _globals['_GREENPLUMCONFIG6_22']._serialized_end=4318
  _globals['_GREENPLUMCONFIGSET6_17']._serialized_start=4321
  _globals['_GREENPLUMCONFIGSET6_17']._serialized_end=4578
  _globals['_GREENPLUMCONFIGSET6_19']._serialized_start=4581
  _globals['_GREENPLUMCONFIGSET6_19']._serialized_end=4838
  _globals['_GREENPLUMCONFIGSET6_21']._serialized_start=4841
  _globals['_GREENPLUMCONFIGSET6_21']._serialized_end=5098
  _globals['_GREENPLUMCONFIGSET6_22']._serialized_start=5101
  _globals['_GREENPLUMCONFIGSET6_22']._serialized_end=5358
  _globals['_GREENPLUMCONFIGSET6']._serialized_start=5361
  _globals['_GREENPLUMCONFIGSET6']._serialized_end=5606
  _globals['_CONNECTIONPOOLERCONFIGSET']._serialized_start=5609
  _globals['_CONNECTIONPOOLERCONFIGSET']._serialized_end=5878
# @@protoc_insertion_point(module_scope)
